@@ -24,6 +24,8 @@ class Merger:
           min_spades_circular_percent=95,
           spades_kmers=None,
           spades_use_first_success=False,
+          spades_careful=True,
+          spades_only_assembler=True,
           ref_end_tolerance=15000,
           qry_end_tolerance=1000,
           verbose=False,
@@ -45,6 +47,8 @@ class Merger:
         self.min_spades_circular_percent = min_spades_circular_percent
         self.spades_kmers = spades_kmers
         self.spades_use_first_success = spades_use_first_success
+        self.spades_careful = spades_careful
+        self.spades_only_assembler = spades_only_assembler
         self.ref_end_tolerance = ref_end_tolerance
         self.qry_end_tolerance = qry_end_tolerance
         self.verbose = verbose
@@ -67,7 +71,7 @@ class Merger:
             diagdiff=self.nucmer_diagdiff,
             maxmatch=True,
             breaklen=self.nucmer_breaklen,
-            simplify=False,
+            simplify=True,
             verbose=self.verbose
         )
         n.run()
@@ -617,7 +621,8 @@ class Merger:
     def _index_fasta(self, infile):
         fai = infile + '.fai'
         if not os.path.exists(fai):
-            circlator.common.syscall('samtools faidx ' + infile, verbose=self.verbose)
+            samtools = circlator.external_progs.make_and_check_prog('samtools')
+            circlator.common.syscall(samtools.exe() + ' faidx ' + infile, verbose=self.verbose)
 
 
     def _write_act_files(self, ref_fasta, qry_fasta, coords_file, outprefix):
@@ -649,7 +654,9 @@ class Merger:
     def _iterative_bridged_contig_pair_merge(self, outprefix):
         '''Iteratively merges contig pairs using bridging contigs from reassembly, until no more can be merged'''
         if self.reads is None:
-            return self.original_fasta, self.reassembly, None, None
+            if self.verbose:
+                print('Skipping iterative contig merging because no reads given (see --reads option)')
+            return self.original_fasta, None, None
 
         log_file = outprefix + '.iterations.log'
         log_fh = pyfastaq.utils.open_file_write(log_file)
@@ -695,6 +702,8 @@ class Merger:
                     reads_prefix + '.fasta',
                     assembler_dir,
                     threads=self.threads,
+                    careful=self.spades_careful,
+                    only_assembler=self.spades_only_assembler,
                     verbose=self.verbose,
                     spades_kmers=self.spades_kmers,
                     spades_use_first_success=self.spades_use_first_success,
